package ca.recrown.islandsurvivalcraft.world;

import java.util.Random;

import org.bukkit.Material;
import org.bukkit.World;
import org.bukkit.generator.ChunkGenerator.BiomeGrid;
import org.bukkit.generator.ChunkGenerator.ChunkData;

import ca.recrown.islandsurvivalcraft.world.generation.BedrockGenerator;
import ca.recrown.islandsurvivalcraft.world.generation.IslandBiomeGenerator;

/**
 * A world generator.
 */
public class IslandWorldGenerator {
    private final int maxHeight;
    private final BedrockGenerator bedrockGenerator;
    private final BiomeSelector biomeSelector;
    private final IslandBiomeGenerator biomeGenerator;
    
    public final World world;
    public final IslandWorldBaseTerrainMap islandMapGenerator;
    public final Random random;
    
    public IslandWorldGenerator(World world, IslandBiomeGenerator generator, Random random) {
        this.world = world;
        this.maxHeight = world.getMaxHeight();
        this.random = random;
        this.biomeSelector = new BiomeSelector(random);
        this.bedrockGenerator = new BedrockGenerator(random);
        this.islandMapGenerator = new IslandWorldBaseTerrainMap(random, world.getSeaLevel(), 4);
        this.biomeGenerator = generator;
        biomeSelector.initialize();
    }

    public void GenerateChunk(int chunkX, int chunkZ, int localX, int localZ, ChunkData chunk, BiomeGrid biomeGrid) {
        int worldX = 16 * chunkX + localX;
        int worldZ = 16 * chunkZ + localZ;
        
        //Sets the biome.
        biomeGenerator.GenerateBiome(chunkX, chunkZ, localX, localZ, biomeGrid);
        
        //Sets the bedrock.
        int bedrockHeight = bedrockGenerator.getBedrockHeight(worldX, worldZ);
        chunk.setRegion(localX, 0, localZ, localX, bedrockHeight, localZ, Material.BEDROCK);
    }
}